/* Cascading Style Sheet, Level 1, for NetHelp */



/* Add the following command in the <HEAD> section of your HTML file */

/* <LINK REL=STYLESHEET TYPE="text/css" HREF="../shared/nethelp1.css"> */



BODY { 

    margin: 0;

    font-family: arial, helvetica, sans-serif; font-size: 14px;

    color: black; 

  }



H1, H2, H3, H4, H5, H6, P, UL, OL, DIR, MENU, DIV, 

DT, DD, ADDRESS, BLOCKQUOTE, PRE, BR, HR { display: block }



B, STRONG, I, EM, CITE, VAR, TT, CODE, KBD, SAMP, 

IMG, SPAN { display: inline }



LI { font-family: arial, helvetica, sans-serif; font-size: 12px }



H1, H2, H3, H4 { margin-top: 0; margin-bottom: 0 }

H5, H6 { margin-top: 0 }

H1 { text-align: left }

H3, H5 { font-style: normal }

H1 { font-family: arial, helvetica, sans-serif; font-size: 18px }

H2 { font-family: arial, helvetica, sans-serif; font-size: 16px }

H3 { font-family: arial, helvetica, sans-serif; font-size: 14px }

H4 { font-family: arial, helvetica, sans-serif; font-size: 12px }

H5 { font-family: arial, helvetica, sans-serif; font-size: 12px }

H6 { font-family: arial, helvetica, sans-serif; font-size: 12px }



P { font-family: arial, helvetica, sans-serif; font-size: 12px; }



B, STRONG { font-weight: bold }  /* relative to the parent */

I, CITE, EM, VAR, ADDRESS { font-style: italic }

PRE, TT, CODE, KBD, SAMP { font-family: monospace }



PRE { white-space: pre }

PRE { font-size: 12px }



ADDRESS { margin-left: 0 }

ADDRESS { font-size: 12px }



BLOCKQUOTE { margin-left: 0; margin-right: 0 }

BLOCKQUOTE { font-family: arial, helvetica, sans-serif; font-size: 12px; }



UL, DIR { list-style: disc }

UL { margin-left: -1em }

UL { font-family: arial, helvetica, sans-serif; font-size: 12px }



OL { list-style: decimal }

OL { margin-left: -1em }

OL { font-family: arial, helvetica, sans-serif; font-size: 12px }



MENU { margin: 0 }              /* tight formatting */



LI { margin-left: 0 }

LI { font-size: 12px }



DT { margin-bottom: 0 }

DT { font-family: arial, helvetica, sans-serif; font-size: 12px }



DD { margin-top: 0 }

DD { margin-left: 1em }

DD { font-family: arial, helvetica, sans-serif; font-size: 12px }



TD { font-family: arial, helvetica, sans-serif;}

TD { font-size: 12px }

TH { font-family: arial, helvetica, sans-serif;}

TH { font-size: 12px }

TR { font-family: arial, helvetica, sans-serif;}

TR { font-size: 12px }



HR { border-top: solid }        /* 'border-bottom' could also have been used */



.keyword {

	font-family: helvetica, arial;
	font-size: 12px;
	text-decoration: none;
	margin-top: 0;
	margin-bottom: 0;
	}

.lookfor {

	font-family: helvetica, arial;
	font-size: 12px;
	text-decoration: none;
	margin-top: -6;
	margin-bottom: 0;
	}
	
.label {

	font-family: helvetica, arial;
	font-size: 12px;
	color: #000066;
	}


.container {
	font-family: helvetica, arial;
 	font-size: 12px;
  	margin-top: 12;
  	margin-bottom: 4;
	color: 000000;
	font-weight:bold;
	}
	
.unselectedItem {
	font-family: helvetica, arial;
 	font-size: 12px;
  	margin-left: 4;
  	margin-top: 8;
  	margin-bottom: 4;
	color: 6600ff;
	}
	
.selectedItem {
	font-family: helvetica, arial;
 	font-size: 12px;
  	margin-left: 4;
  	margin-top: 8;
  	margin-bottom: 4;
	color: 6600ff;
	font-weight: bold;
	}
	
.tocintrotext {
	font-family: helvetica, arial;
 	font-size: 12px;
  	margin-top: 0;
  	margin-bottom: 4;
	color: 000000;
	}
	
	
	



